==> AsposeCellsCloud-CellsApi-24.10.tar.gz: AsposeCellsCloud-CellsApi-24.10/docs/PivotTable.md <==
# AsposeCellsCloud::Object::PivotTable 

## Load the model package
```perl
use AsposeCellsCloud::Object::PivotTable;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**AltTextDescription** | **string** |  |
**AltTextTitle** | **string** |  |
**AutoFormatType** | **string** |  |
**BaseFields** | **ARRAY[PivotField]** |  |
**ColumnFields** | **ARRAY[PivotField]** |  |
**ColumnGrand** | **boolean** |  |
**ColumnHeaderCaption** | **string** |  |
**ColumnRange** | **CellArea** |  |
**CustomListSort** | **boolean** |  |
**DataBodyRange** | **CellArea** |  |
**DataField** | **PivotField** |  |
**DataFields** | **ARRAY[PivotField]** |  |
**DataSource** | **ARRAY[string]** |  |
**DisplayErrorString** | **boolean** |  |
**DisplayImmediateItems** | **boolean** |  |
**DisplayNullString** | **boolean** |  |
**EnableDataValueEditing** | **boolean** |  |
**EnableDrilldown** | **boolean** |  |
**EnableFieldDialog** | **boolean** |  |
**EnableFieldList** | **boolean** |  |
**EnableWizard** | **boolean** |  |
**ErrorString** | **string** |  |
**FieldListSortAscending** | **boolean** |  |
**GrandTotalName** | **string** |  |
**HasBlankRows** | **boolean** |  |
**Indent** | **int** |  |
**IsAutoFormat** | **boolean** |  |
**IsGridDropZones** | **boolean** |  |
**IsMultipleFieldFilters** | **boolean** |  |
**IsSelected** | **boolean** |  |
**ItemPrintTitles** | **boolean** |  |
**ManualUpdate** | **boolean** |  |
**MergeLabels** | **boolean** |  |
**MissingItemsLimit** | **string** |  |
**Name** | **string** | Represents pivot table name. |
**NullString** | **string** |  |
**PageFieldOrder** | **string** |  |
**PageFields** | **ARRAY[PivotField]** |  |
**PageFieldWrapCount** | **int** |  |
**PivotFilters** | **ARRAY[PivotFilter]** |  |
**PivotTableStyleName** | **string** |  |
**PivotTableStyleType** | **string** |  |
**PreserveFormatting** | **boolean** |  |
**PrintDrill** | **boolean** |  |
**PrintTitles** | **boolean** |  |
**RefreshDataFlag** | **boolean** |  |
**RefreshDataOnOpeningFile** | **boolean** |  |
**RowFields** | **ARRAY[PivotField]** |  |
**RowGrand** | **boolean** |  |
**RowHeaderCaption** | **string** |  |
**RowRange** | **CellArea** |  |
**SaveData** | **boolean** |  |
**ShowDataTips** | **boolean** |  |
**ShowDrill** | **boolean** |  |
**ShowEmptyCol** | **boolean** |  |
**ShowEmptyRow** | **boolean** |  |
**ShowMemberPropertyTips** | **boolean** |  |
**ShowPivotStyleColumnHeader** | **boolean** |  |
**ShowPivotStyleColumnStripes** | **boolean** |  |
**ShowPivotStyleLastColumn** | **boolean** |  |
**ShowPivotStyleRowHeader** | **boolean** |  |
**ShowPivotStyleRowStripes** | **boolean** |  |
**ShowRowHeaderCaption** | **boolean** |  |
**ShowValuesRow** | **boolean** |  |
**SubtotalHiddenPageItems** | **boolean** |  |
**TableRange1** | **CellArea** |  |
**TableRange2** | **CellArea** |  |
**Tag** | **string** |  |
**link** | **Link** |  |  

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> AsposeCellsCloud-CellsApi-25.4.tar.gz: AsposeCellsCloud-CellsApi-25.4/docs/PivotTable.md <==
# AsposeCellsCloud::Object::PivotTable 

## Load the model package
```perl
use AsposeCellsCloud::Object::PivotTable;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**AltTextDescription** | **string** | Gets the description of the alt text |
**AltTextTitle** | **string** |  |
**AutoFormatType** | **string** |  |
**BaseFields** | **ARRAY[PivotField]** |  |
**ColumnFields** | **ARRAY[PivotField]** |  |
**ColumnGrand** | **boolean** |  |
**ColumnHeaderCaption** | **string** |  |
**ColumnRange** | **CellArea** |  |
**CustomListSort** | **boolean** |  |
**DataBodyRange** | **CellArea** |  |
**DataField** | **PivotField** |  |
**DataFields** | **ARRAY[PivotField]** |  |
**DataSource** | **ARRAY[string]** |  |
**DisplayErrorString** | **boolean** |  |
**DisplayImmediateItems** | **boolean** |  |
**DisplayNullString** | **boolean** |  |
**EnableDataValueEditing** | **boolean** |  |
**EnableDrilldown** | **boolean** |  |
**EnableFieldDialog** | **boolean** |  |
**EnableFieldList** | **boolean** |  |
**EnableWizard** | **boolean** |  |
**ErrorString** | **string** |  |
**FieldListSortAscending** | **boolean** |  |
**GrandTotalName** | **string** |  |
**HasBlankRows** | **boolean** |  |
**Indent** | **int** |  |
**IsAutoFormat** | **boolean** |  |
**IsGridDropZones** | **boolean** |  |
**IsMultipleFieldFilters** | **boolean** |  |
**IsSelected** | **boolean** |  |
**ItemPrintTitles** | **boolean** |  |
**ManualUpdate** | **boolean** |  |
**MergeLabels** | **boolean** |  |
**MissingItemsLimit** | **string** |  |
**Name** | **string** | Represents pivot table name. |
**NullString** | **string** |  |
**PageFieldOrder** | **string** |  |
**PageFields** | **ARRAY[PivotField]** |  |
**PageFieldWrapCount** | **int** |  |
**PivotFilters** | **ARRAY[PivotFilter]** |  |
**PivotTableStyleName** | **string** |  |
**PivotTableStyleType** | **string** |  |
**PreserveFormatting** | **boolean** |  |
**PrintDrill** | **boolean** |  |
**PrintTitles** | **boolean** |  |
**RefreshDataFlag** | **boolean** |  |
**RefreshDataOnOpeningFile** | **boolean** |  |
**RowFields** | **ARRAY[PivotField]** |  |
**RowGrand** | **boolean** |  |
**RowHeaderCaption** | **string** |  |
**RowRange** | **CellArea** |  |
**SaveData** | **boolean** |  |
**ShowDataTips** | **boolean** |  |
**ShowDrill** | **boolean** |  |
**ShowEmptyCol** | **boolean** |  |
**ShowEmptyRow** | **boolean** |  |
**ShowMemberPropertyTips** | **boolean** |  |
**ShowPivotStyleColumnHeader** | **boolean** |  |
**ShowPivotStyleColumnStripes** | **boolean** |  |
**ShowPivotStyleLastColumn** | **boolean** |  |
**ShowPivotStyleRowHeader** | **boolean** |  |
**ShowPivotStyleRowStripes** | **boolean** |  |
**ShowRowHeaderCaption** | **boolean** |  |
**ShowValuesRow** | **boolean** |  |
**SubtotalHiddenPageItems** | **boolean** |  |
**TableRange1** | **CellArea** |  |
**TableRange2** | **CellArea** |  |
**Tag** | **string** |  |
**link** | **Link** |  |  

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
